#ifndef SETTINGS_H
#define SETTINGS_H

#include <QtCore>
#include <QtGui>
#include "qemaemo5dynamichomescreenwidget.h"
#include "qesettingsmanager.h"
#include <QDialog>


namespace Ui {
    class Settings;
}

class Settings : public QDialog
{
    Q_OBJECT

public:
    explicit Settings(QWidget *parent = 0);
    ~Settings();

public slots:
    void LoadAll();
    void GetProgram(QString file);

private slots:
    void on_pushButton_11_clicked();
    void on_checkBox_stateChanged(int );
    void on_pushButton_clicked();
    void on_pushButton_2_clicked();
    void on_pushButton_3_clicked();
    void on_pushButton_4_clicked();
    void on_pushButton_5_clicked();
    void on_pushButton_6_clicked();
    void on_pushButton_7_clicked();
    void on_pushButton_8_clicked();
    void on_pushButton_9_clicked();
    void on_pushButton_10_clicked();

private:
    Ui::Settings *ui;
};

#endif // SETTINGS_H
